package com.ruoyi.web.controller.system.count;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.entity.SysDictData;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TdFileProvide;
import com.ruoyi.system.domain.TdFileReceive;
import com.ruoyi.system.service.ISysDictDataService;
import com.ruoyi.system.service.ITdFileProvideService;
import com.ruoyi.system.service.ITdFileReceiveService;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.atomic.AtomicReference;
import java.util.stream.Collectors;

/**
 * 涉密文件统计
 */
@Controller
@RequestMapping("/system/filenum")
public class SysFilenumController extends BaseController {
    private String prefix = "system/fileprovide/filenum";

    @Autowired
    private ITdFileProvideService tdFileProvideService;
    @Autowired
    private ITdFileReceiveService tdFileReceiveService;

    @RequiresPermissions("system:filenum:view")
    @GetMapping()
    public String fileprovide()
    {
        return prefix + "/filenum";
    }

    /**
     * 查询文件下发列表
     */
    @RequiresPermissions("system:filenum:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(TdFileProvide tdFileProvide)
    {
        startPage();
        List<TdFileProvide> list = tdFileProvideService.selectTdFileProvideList(tdFileProvide);
        return getDataTable(list);
    }

    /**
     * 打印界面，根据文件编号区分
     */
    @RequiresPermissions("system:filenum:print")
    @GetMapping("/print/{fileId}")
    @Log(title = "文件统计", businessType = BusinessType.PRINT)
    public String print(@PathVariable("fileId") String fileId, ModelMap mmap)
    {
        List<TdFileReceive> tdFileReceives = tdFileReceiveService.selectTdFileReceiveByFileId(fileId);
        TdFileProvide tdFileProvide = tdFileProvideService.selectTdFileProvideByFileId(fileId);
        mmap.put("tdFileReceives", tdFileReceives);
        mmap.put("tdFileProvide", tdFileProvide);
        mmap.put("sysuser", getSysUser());
        return prefix + "/print";
    }

    @Autowired
    private ISysDictDataService dictDataService;

    /**
     * 
     *  载体类型统计
     * @return com.ruoyi.common.core.domain.AjaxResult
     */
    
    @PostMapping("/countLevel")
    @ResponseBody
    public AjaxResult countLevel() {
        SysDictData sysDictData =  new SysDictData();
        sysDictData.setDictType("sys_provide_level");
        List<SysDictData> smType = dictDataService.selectDictDataList(sysDictData);
        List<String> list = smType.stream().map(SysDictData::getDictLabel).collect(Collectors.toList());
        List<Long> yAxisData = new ArrayList<>();
        smType.forEach(xAxis -> {
            AtomicReference<Long> yAxis = new AtomicReference<>(0L);
            Integer count = tdFileProvideService.lambdaQuery()
                    .eq(TdFileProvide::getProvideLevel, xAxis.getDictValue())
                    .count();
            yAxis.set(Long.valueOf(count));

            yAxisData.add(yAxis.get());
        });
        JSONObject obj = new JSONObject();
        obj.put("xAxisData", list.toArray());
        obj.put("yAxisData", yAxisData);
        return AjaxResult.success(obj);
    }


    /**
     *
     *  载体密级统计
     * @return com.ruoyi.common.core.domain.AjaxResult
     */
    @PostMapping("/countSecret")
    @ResponseBody
    public AjaxResult countSecret() {
        SysDictData sysDictData =  new SysDictData();
        sysDictData.setDictType("sys_file_miji");
        List<SysDictData> smType = dictDataService.selectDictDataList(sysDictData);
        List<JSONObject> jsonObjects = new ArrayList<>();
        smType.forEach(xAxis -> {
            AtomicReference<Long> value = new AtomicReference<>(0L);
            Integer count = tdFileProvideService.lambdaQuery()
                    .eq(TdFileProvide::getFileSecret, xAxis.getDictValue())
                    .count();
            value.set(Long.valueOf(count));
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("value", value.get());
            jsonObject.put("name", xAxis.getDictLabel());
            jsonObjects.add(jsonObject);
        });
        return AjaxResult.success(jsonObjects);
    }


}
